@@ -25,29 +25,28 @@ class VocabularyFilter;
 
 namespace Editor
 {
-
 class LatexWidget : public QWidget, public Ui::LatexWidget
 {
     Q_OBJECT
 
 public:
-    LatexWidget(VocabularyFilter *model, KEduVocDocument *doc, QWidget *parent = 0);
-    ~LatexWidget();
+    LatexWidget(VocabularyFilter *model, KEduVocDocument *doc, QWidget *parent = nullptr);
+    ~LatexWidget() override;
 
 public slots:
     /**
-    * Sets the selected word (KEduVocExpression) from the vocabularyView
-    */
+     * Sets the selected word (KEduVocExpression) from the vocabularyView
+     */
     void setTranslation(KEduVocExpression *entry, int translation);
 
     /**
-    * Called when a KEduVocDocument change happened
-    */
+     * Called when a KEduVocDocument change happened
+     */
     void slotDocumentChanged(KEduVocDocument *doc);
 
     /**
-    * Called when the selection changed in the vocabulary view
-    */
+     * Called when the selection changed in the vocabulary view
+     */
     void slotSelectionChanged(const QItemSelection &, const QItemSelection &);
 
     void checkBoxToggled();
@@ -55,29 +54,30 @@ public slots:
     void updateLatex();
 
 private:
-    VocabularyFilter *m_model;
-    KEduVocDocument *m_doc;
-    QDataWidgetMapper *m_mapper;
-    KEduVocTranslation *m_translation;
+    VocabularyFilter *m_model{nullptr};
+    KEduVocDocument *m_doc{nullptr};
+    QDataWidgetMapper *m_mapper{nullptr};
+    KEduVocTranslation *m_translation{nullptr};
     QLabel m_hiddenLabel;
-    Practice::LatexRenderer *m_renderer;
+    Practice::LatexRenderer *m_renderer{nullptr};
 };
 
 class LatexDelegate : public QItemDelegate
 {
     Q_OBJECT
 public:
-    explicit LatexDelegate(QObject *parent = 0);
+    explicit LatexDelegate(QObject *parent = nullptr);
 
-    void setEditorData(QWidget *editor, const QModelIndex &index) const Q_DECL_OVERRIDE;
-    void setModelData(QWidget * editor, QAbstractItemModel * model, const QModelIndex & index) const Q_DECL_OVERRIDE;
-    void setMathModeCheckBox(QCheckBox *checkBox) {
+    void setEditorData(QWidget *editor, const QModelIndex &index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const override;
+    void setMathModeCheckBox(QCheckBox *checkBox)
+    {
         m_checkBox = checkBox;
     }
 
 private:
-    QCheckBox *m_checkBox;
+    QCheckBox *m_checkBox{nullptr};
 };
 }
 
-#endif //LATEXWIDGET_H
+#endif // LATEXWIDGET_H
